==> pipgui-1.1.tar.gz: pipgui-1.1/README.md <==
<p align="center">
	<img src="https://user-images.githubusercontent.com/30529572/72455010-fb38d400-37e7-11ea-9c1e-8cdeb5f5906e.png" />
	<h2 align="center"> PIP-GUI </h2>
	<h4 align="center"> A GUI framework for managing PIP packages developed using PyQt5 </h4>
  <h2 align="center"> Description </h2>
  
  ### The Start Screen
  
  ![alt text](readme/startScreen.png?raw=true "Start Window")

  The start screen contains options for a user to select the process he wants to be carried out.

  One can also specify the version of python he wants the operations to be performed upon.

  The file menu has an option to "Exit" (shortcut: Ctrl+Q) and "Refresh Lists" which refreshes the resources files containing package     data.


  ### The Installation Screen
  ![alt text](readme/installScreen.png?raw=true "Installation Window")

  The installation screen has a search bar which the user can use to search and install desired package(s).


  ### The Update Screen
  ![alt text](readme/updateScreen.png?raw=true "Updation Window")

  The update screen displays the list of packages which are out-of-date and can be upgraded.


  ### The Uninstall Screem
  ![alt text](readme/uninstallScreen.png?raw=true "Uninstallation Window")

  The uninstallation screen displays the list of packages which are installed in the user's system and can be uninstalled.


  ### The Progress Window
  ![alt text](readme/progressWindow.png?raw=true "Progress Window")

  The progress window is an built-in terminal widget for PIP-GUI which displays the processes running while performing operations
 </p>



## Functionalities
- [x]  Install/Uninstall pip packages in the active environment
- [x]  Update packages
- [x]  Get the latest packages directly from the pypi package directory
- [ ]  Choose enviroment to download packages
- [ ]  Search option in updates and uninstall windows
- [ ]  Installing package in user directory (--user)

<br>


## Instructions to run

* Pre-requisites:
  - Python version > 3
  
* Install the package using 
```bash
pip install pipgui==1.1
```

* Directions to run the package
  - Type the following command in the terminal
 ```bash
 pipgui
 ```

<br>

## Contributors

* [Ayush Priya](https://github.com/ayushpriya10)
* [zdenop](https://github.com/zdenop)
* [Geek-ubaid](https://github.com/Geek-ubaid)
* [ujjwal96](https://github.com/ujjwal96)
* [L04DB4L4NC3R](https://github.com/L04DB4L4NC3R)


<br>
<br>

<p align="center">
	Made with :heart: by DSC VIT
</p>

==> pipgui-1.4.tar.gz: pipgui-1.4/README.md <==
<p align="center">
	<img src="https://user-images.githubusercontent.com/30529572/72455010-fb38d400-37e7-11ea-9c1e-8cdeb5f5906e.png" />
	<h2 align="center"> PIP-GUI </h2>
	<h4 align="center"> A GUI framework for managing PIP packages developed using PyQt5 </h4>
  <h2 align="center"> Description </h2>
  
  ### The Start Screen
  
  ![alt text](readme/startScreen.png?raw=true "Start Window")

  The start screen contains options for a user to select the process he wants to be carried out.

  One can also specify the version of python he wants the operations to be performed upon.

  The file menu has an option to "Exit" (shortcut: Ctrl+Q) and "Refresh Lists" which refreshes the resources files containing package     data.


  ### The Installation Screen
  ![alt text](readme/installScreen.png?raw=true "Installation Window")

  The installation screen has a search bar which the user can use to search and install desired package(s).


  ### The Update Screen
  ![alt text](readme/updateScreen.png?raw=true "Updation Window")

  The update screen displays the list of packages which are out-of-date and can be upgraded.


  ### The Uninstall Screem
  ![alt text](readme/uninstallScreen.png?raw=true "Uninstallation Window")

  The uninstallation screen displays the list of packages which are installed in the user's system and can be uninstalled.


  ### The Progress Window
  ![alt text](readme/progressWindow.png?raw=true "Progress Window")

  The progress window is an built-in terminal widget for PIP-GUI which displays the processes running while performing operations
 </p>



## Functionalities
- [x]  Install/Uninstall pip packages in the active environment
- [x]  Update packages
- [x]  Get the latest packages directly from the pypi package directory
- [ ]  Choose enviroment to download packages
- [ ]  Search option in updates and uninstall windows
- [ ]  Installing package in user directory (--user)

<br>


## Instructions to Install package

* Pre-requisites:
  - Python version >=3.4
  
* Install the package using 
  ```bash
  pip install pipgui
  ```

* Directions to run the package
  - Type the following command in the terminal
    ```bash
    pipgui
    ```

## Running package locally

* Pre-requisities
  - Python (>=3.4) 

* Install the package locally by using the following commands
  ``` bash
    git clone https://github.com/GDGVIT/pip-gui.git
    cd pipgui
    pip install -e .
  ``` 
* Type the following commmand to run the application
  ``` bash
    pipgui
  ```
<br>

## Contributors

* [Ayush Priya](https://github.com/ayushpriya10)
* [zdenop](https://github.com/zdenop)
* [Geek-ubaid](https://github.com/Geek-ubaid)
* [ujjwal96](https://github.com/ujjwal96)
* [L04DB4L4NC3R](https://github.com/L04DB4L4NC3R)


<br>
<br>

<p align="center">
	Made with :heart: by DSC VIT
</p>
